@@ -21,14 +21,18 @@
 window.addEventListener("load", ubuntuitLoad, false);
 
 function ubuntuitLoad() {
-	gBrowser.addProgressListener(ubuntuitProgress);
+	if (typeof gBrowser == 'object') {
+		gBrowser.addProgressListener(ubuntuitProgress);
+	}
 	ubuntuitCommon.onLoad();
 }
 
 window.addEventListener("unload", ubuntuitUnload, false);
 
 function ubuntuitUnload() {
-	gBrowser.removeProgressListener(ubuntuitProgress);
+	if (typeof gBrowser == 'object') {
+		gBrowser.removeProgressListener(ubuntuitProgress);
+	}
 }
 
 function ubuntuitCheckStatus() {
@@ -121,21 +125,21 @@ var ubuntuitCommon = {
 		var data = new Date();
 		var month = new Array("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
 		var url = "https://lists.ubuntu.com/archives/ubuntu-it/" + data.getFullYear() + "-" + month[data.getMonth()] + "/" + type + ".html";
-		ubuntuitUrl.openClearLink(event, url);			
+		ubuntuitUrl.openClearLink(event, url);
 	},
 
 	onMenuLoad: function(numero) {
 		var prefs = this.getPrefs();
 		var win = this.getMainWin();
-		var prefNames = new Array('HomeLink', 'MainMenu', 'WikiMenu', 'IrcMenu', 'MailMenu', 'UtiliMenu', 'ForumMenu', 'PersForumMenu', 'ForumForumMenu', 'SectionsForumMenu', 'Options');
+		var prefNames = new Array('HomeLink', 'SearchLink', 'MainMenu', 'WikiMenu', 'IrcMenu', 'MailMenu', 'UtiliMenu', 'ForumMenu', 'PersForumMenu', 'ForumForumMenu', 'SectionsForumMenu', 'Options');
 		var multipleID = '';
 
-		for (var y = 0; y <= 10; y++)
+		for (var y = 0; y <= 11; y++)
 		{
 			multipleID = 'ubuntuit' + prefNames[y] + numero;
-            		win.document.getElementById(multipleID).setAttribute('hidden', !prefs.getBoolPref(prefNames[y]));
+			win.document.getElementById(multipleID).setAttribute('hidden', !prefs.getBoolPref(prefNames[y]));
 		}
-            		win.document.getElementById('ubuntuitSepOptions' + numero).setAttribute('hidden', !prefs.getBoolPref('Options'));
+		win.document.getElementById('ubuntuitSepOptions' + numero).setAttribute('hidden', !prefs.getBoolPref('Options'));
 	},
 
 	onSubMenuLoad: function(menu) {
@@ -146,7 +150,8 @@ var ubuntuitCommon = {
 		var derpref = false;
 		var derPrefSet = prefs.getCharPref('DerLinks');
 		var submenu = menu.substr(0, menu.length - 1);
-		derpref = (derPrefSet == ',,,,' || (derPrefSet.substr(0, 3) != 'Kub' && submenu == 'ForumMenu') || (derPrefSet == ',,,Gob,' && submenu != 'MainMenu'));
+		derpref = (derPrefSet == ',,,' || (derPrefSet.substr(0,3) != 'Kub' && submenu == 'ForumMenu'));
+
 		multipleDerID = 'ubuntuitDer' + menu;
 		win.document.getElementById(multipleDerID).setAttribute('hidden', derpref);
 		
@@ -166,9 +171,9 @@ var ubuntuitCommon = {
 			var myhome = prefs.getCharPref('myWikiHomepage');
 			var wikiMyHome = 'ubuntuitWikiHomepage' + numero;
 			if (myhome == '') {
-		            	win.document.getElementById(wikiMyHome).setAttribute('hidden', true);
+				win.document.getElementById(wikiMyHome).setAttribute('hidden', true);
 			} else {
-		            	win.document.getElementById(wikiMyHome).setAttribute('hidden', false);
+				win.document.getElementById(wikiMyHome).setAttribute('hidden', false);
 			}
 		}
 	},
@@ -180,24 +185,24 @@ var ubuntuitCommon = {
 		var myhome = prefs.getCharPref('myLPHomepage');
 		var LPMyHome = 'ubuntuitLPHomepage' + numero;
 		if (myhome == '') {
-	            	win.document.getElementById(LPMyHome).setAttribute('hidden', true);
+			win.document.getElementById(LPMyHome).setAttribute('hidden', true);
 		} else {
-	            	win.document.getElementById(LPMyHome).setAttribute('hidden', false);
+			win.document.getElementById(LPMyHome).setAttribute('hidden', false);
 		}
 	},
 
-	onDerMenuLoad: function(menu, kub, edub, xub, gob) {
+	onDerMenuLoad: function(menu, kub, edub, xub) {
 		var prefs = this.getPrefs();
 		var win = this.getMainWin();
 		var derPrefsExpl = prefs.getCharPref('DerLinks').split(',');
-		var derNames = new Array('Kub', 'Edub', 'Xub', 'Gob');
-		var derId = new Array('ubuntuitDerK', 'ubuntuitDerE', 'ubuntuitDerX', 'ubuntuitDerG');
+		var derNames = new Array('Kub', 'Edub', 'Xub');
+		var derId = new Array('ubuntuitDerK', 'ubuntuitDerE', 'ubuntuitDerX');
 		var derSep = new Array(1, 3, 5);
 		var multipleDerID = '';
 		var derpreferenza = false;
-		var derMaxNumber = new Array(kub, edub, xub, gob);
+		var derMaxNumber = new Array(kub, edub, xub);
 
-		for (var y = 0; y <= 3; y++)
+		for (var y = 0; y < 3; y++)
 		{
 			derpreferenza = (derPrefsExpl[y] != derNames[y]);
 			for (var t = 1; t <= derMaxNumber[y]; t++) {
@@ -208,9 +213,8 @@ var ubuntuitCommon = {
 
 		var duesep = menu.substr(0, menu.length - 1);
 		if(duesep == 'WikiMenu' || duesep == 'IrcMenu' || duesep == 'MailMenu') {
-			// cicle stop before Gobuntu
 			var derSepPoint = 0;
-			for (var y = 0; y <= 2; y++)
+			for (var y = 0; y < 3; y++)
 			{
 				if(derPrefsExpl[y] == derNames[y]) derSepPoint += derSep[y];
 			}
@@ -247,10 +251,10 @@ var ubuntuitCommon = {
 			var myhome = prefs.getCharPref('myIntWikiHomepage');
 			var wikiMyHome = 'ubuntuitIntWikiHomepage' + numero;
 			if(intPrefsExpl[0] != intNames[0]) {
-			            	win.document.getElementById(wikiMyHome).setAttribute('hidden', true);
-			} else {	
+				win.document.getElementById(wikiMyHome).setAttribute('hidden', true);
+			} else {
 				var viewhome = (myhome == '');
-		            	win.document.getElementById(wikiMyHome).setAttribute('hidden', viewhome);
+				win.document.getElementById(wikiMyHome).setAttribute('hidden', viewhome);
 			}
 		}
 
@@ -273,4 +277,4 @@ var ubuntuitCommon = {
 			win.document.getElementById('ubuntuitIntSep3' + genmenu + numero).setAttribute('hidden', intmainsep3);
 		}
 	},
-};
\ No newline at end of file
+};
