@@ -40,6 +40,7 @@ var ubuntuitOptions = {
 		document.getElementById('ContextMenu').checked = prefs.getBoolPref('ContextMenu');
 		document.getElementById('ShowLogo').checked = prefs.getBoolPref('ShowLogo');
 		document.getElementById('HomeLink').checked = prefs.getBoolPref('HomeLink');
+		document.getElementById('SearchLink').checked = prefs.getBoolPref('SearchLink');
 		document.getElementById('MainMenu').checked = prefs.getBoolPref('MainMenu');
 		document.getElementById('WikiMenu').checked = prefs.getBoolPref('WikiMenu');
 		document.getElementById('IrcMenu').checked = prefs.getBoolPref('IrcMenu');
@@ -55,11 +56,11 @@ var ubuntuitOptions = {
 		document.getElementById('myLPHomepage').value = prefs.getCharPref('myLPHomepage');
 
 		var derPrefsExpl = prefs.getCharPref('DerLinks').split(',');
-		var derNames = new Array('Kub', 'Edub', 'Xub', 'Gob');
-		var derIdNames = new Array('DerKub', 'DerEdub', 'DerXub', 'DerGob');
+		var derNames = new Array('Kub', 'Edub', 'Xub');
+		var derIdNames = new Array('DerKub', 'DerEdub', 'DerXub');
 		var dercontrollo;
 
-		for (var y = 0; y <= 3; y++)
+		for (var y = 0; y < 3; y++)
 		{
 			dercontrollo = (derPrefsExpl[y] == derNames[y]);
 			document.getElementById(derIdNames[y]).checked = dercontrollo;
@@ -87,6 +88,7 @@ var ubuntuitOptions = {
 		prefs.setBoolPref('ContextMenu',document.getElementById('ContextMenu').checked);
 		prefs.setBoolPref('ShowLogo',document.getElementById('ShowLogo').checked);
 		prefs.setBoolPref('HomeLink',document.getElementById('HomeLink').checked);
+		prefs.setBoolPref('SearchLink',document.getElementById('SearchLink').checked);
 		prefs.setBoolPref('MainMenu',document.getElementById('MainMenu').checked);
 		prefs.setBoolPref('WikiMenu',document.getElementById('WikiMenu').checked);
 		prefs.setBoolPref('IrcMenu',document.getElementById('IrcMenu').checked);
@@ -102,11 +104,11 @@ var ubuntuitOptions = {
 		prefs.setCharPref('myIntWikiHomepage',document.getElementById('myIntWikiHomepage').value);
 		prefs.setCharPref('myLPHomepage',document.getElementById('myLPHomepage').value);
 
-		var derNames = new Array('Kub', 'Edub', 'Xub', 'Gob');
-		var derIdNames = new Array('DerKub', 'DerEdub', 'DerXub', 'DerGob');
+		var derNames = new Array('Kub', 'Edub', 'Xub');
+		var derIdNames = new Array('DerKub', 'DerEdub', 'DerXub');
 		var derPref = '';
 
-		for (var y = 0; y <= 3; y++)
+		for (var y = 0; y < 3; y++)
 		{
 			var checkDerElement = document.getElementById(derIdNames[y]);
 			if (checkDerElement.checked) {
@@ -130,4 +132,4 @@ var ubuntuitOptions = {
 		}
 		prefs.setCharPref('IntLinks', intPref);
 	},
-};
\ No newline at end of file
+};
