@@ -23,6 +23,7 @@ pref('extensions.ubuntuit.ToolsMenu', true);
 pref('extensions.ubuntuit.ContextMenu', true);
 pref('extensions.ubuntuit.ShowLogo', true);
 pref('extensions.ubuntuit.HomeLink', true);
+pref('extensions.ubuntuit.SearchLink', true);
 pref('extensions.ubuntuit.MainMenu', true);
 pref('extensions.ubuntuit.WikiMenu', true);
 pref('extensions.ubuntuit.IrcMenu', true);
@@ -30,11 +31,11 @@ pref('extensions.ubuntuit.MailMenu', true);
 pref('extensions.ubuntuit.UtiliMenu', true);
 pref('extensions.ubuntuit.ForumMenu', true);
 pref('extensions.ubuntuit.Options', true);
-pref('extensions.ubuntuit.DerLinks', 'Kub,Edub,Xub,Gob,');
+pref('extensions.ubuntuit.DerLinks', 'Kub,Edub,Xub,');
 pref('extensions.ubuntuit.IntLinks', 'INT,FR,DE,ES,');
 pref('extensions.ubuntuit.PersForumMenu', true);
 pref('extensions.ubuntuit.ForumForumMenu', true);
 pref('extensions.ubuntuit.SectionsForumMenu', true);
 pref('extensions.ubuntuit.myWikiHomepage', '');
 pref('extensions.ubuntuit.myIntWikiHomepage', '');
-pref('extensions.ubuntuit.myLPHomepage', '');
\ No newline at end of file
+pref('extensions.ubuntuit.myLPHomepage', '');
